@@ -1,5 +1,5 @@
 '''
-session
+Session
 =======
 
 The following methods allow for interaction into the Tenable.io
@@ -9,24 +9,17 @@ Methods available on ``tio.session``:
 
 .. rst-class:: hide-signature
 .. autoclass:: SessionAPI
-
-    .. automethod:: change_password
-    .. automethod:: details
-    .. automethod:: edit
-    .. automethod:: gen_api_keys
-    .. automethod:: two_factor
-    .. automethod:: enable_two_factor
-    .. automethod:: verify_two_factor
-    .. automethod:: restore
+    :members:
 '''
 from .base import TIOEndpoint
-from tenable.errors import ImpersonationError, UnknownError
+
 
 class SessionAPI(TIOEndpoint):
     '''
     Tenable.io session API is deprecated.
     it is recommended to use ``users`` endpoint instead
     '''
+
     def edit(self, name, email):
         '''
         Modify the currently logged-in user.
