@@ -1,5 +1,5 @@
 '''
-asset_lists
+Asset Lists
 ===========
 
 The following methods allow for interaction into the Tenable.sc
@@ -10,12 +10,7 @@ Methods available on ``sc.asset_lists``:
 
 .. rst-class:: hide-signature
 .. autoclass:: AssetListAPI
-
-    .. automethod:: create
-    .. automethod:: delete
-    .. automethod:: details
-    .. automethod:: edit
-    .. automethod:: list
+    :members:
 '''
 from .base import SCEndpoint
 from tenable.errors import UnexpectedValueError
@@ -63,7 +58,7 @@ class AssetListAPI(SCEndpoint):
                     'type': 'clause',
                     'filterName': self._check('rule:name', rule[0], str,
                         choices=['dns', 'exploitAvailable', 'exploitFrameworks',
-                            'firstseen', 'mac', 'os', 'ip', 'lastseen',
+                            'firstseen', 'mac', 'os', 'ip', 'uuid', 'lastseen',
                             'netbioshost', 'netbiosworkgroup', 'pluginid',
                             'plugintext', 'port', 'severity', 'sshv1', 'sshv2',
                             'tcpport', 'udpport', 'xref']),
@@ -390,7 +385,7 @@ class AssetListAPI(SCEndpoint):
 
                 * Available rules are ``dns``, ``exploitAvailable``,
                   ``exploitFrameworks``, ``firstseen``, ``mac``, ``os``, ``ip``,
-                  ``lastseen``, ``netbioshost``, ``netbiosworkgroup``,
+                  ``uuid``, ``lastseen``, ``netbioshost``, ``netbiosworkgroup``,
                   ``pluginid``, ``plugintext``, ``port``, ``severity``, ``sshv1``,
                   ``sshv2``, ``tcpport``, ``udpport``, and ``xref``.
                 * Available operators are ``contains``, ``eq``, ``lt``, ``lte``,
@@ -440,15 +435,15 @@ class AssetListAPI(SCEndpoint):
         payload = self._constructor(**kw)
         return self._api.post('asset', json=payload).json()['response']
 
-    def details(self, id, orgID, fields=None):
+    def details(self, id, org_id=None, fields=None):
         '''
         Returns the details for a specific asset-list.
 
-        :sc-api:`asset-list: details<Asset.html#AssetRESTReference-/asset/{id}?orgID={orgID}>`
+        :sc-api:`asset-list: details<Asset.html#AssetRESTReference-/asset/{id}?orgID={org_id}>`
 
         Args:
             id (int): The identifier for the asset-list.
-            orgID (int): The organizationID for the asset-list.
+            org_id (int, optional): The organizationID for the asset-list.
             fields (list, optional): A list of attributes to return.
 
         Returns:
@@ -461,7 +456,8 @@ class AssetListAPI(SCEndpoint):
         params = dict()
         if fields:
             params['fields'] = ','.join([self._check('field', f, str) for f in fields])
-        params['orgID']   = orgID
+        if org_id:
+            params['orgID'] = org_id
         return self._api.get('asset/{}'.format(self._check('id', id,int)),params=params).json()['response']
 
     def edit(self, id, **kw):
